pub trait AsyncExecutor {
// Required method
fn block_on<T>(&self, future: impl Future<Output = T>) -> T;
}Expand description
Plugin trait used to allow benchmarking on multiple different async runtimes.
Smol, Tokio and Async-std are supported out of the box, as is the current-thread runner from the Futures crate; it is recommended to use whichever runtime you use in production.
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".